@@ -16,8 +16,12 @@
 
 package helmv3
 
+import "github.com/hashicorp/go-multierror"
+
 // HelmV3 struct implements the IacProvider interface
-type HelmV3 struct{}
+type HelmV3 struct {
+	errIacLoadDirs *multierror.Error
+}
 
 type helmChartData map[string]interface{}
 
