@@ -13,10 +13,6 @@ import (
 	"github.com/hashicorp/go-multierror"
 )
 
-var (
-	errIacLoadDirs *multierror.Error = nil
-)
-
 func (*K8sV1) getFileType(file string) string {
 	if strings.HasSuffix(file, YAMLExtension) {
 		return YAMLExtension
@@ -30,13 +26,15 @@ func (*K8sV1) getFileType(file string) string {
 
 // LoadIacDir loads all k8s files in the current directory
 func (k *K8sV1) LoadIacDir(absRootDir string, nonRecursive bool) (output.AllResourceConfigs, error) {
+	// set the root directory being scanned
+	k.absRootDir = absRootDir
 
 	allResourcesConfig := make(map[string][]output.ResourceConfig)
 
 	fileMap, err := utils.FindFilesBySuffix(absRootDir, K8sFileExtensions())
 	if err != nil {
 		zap.S().Debug("error while searching for iac files", zap.String("root dir", absRootDir), zap.Error(err))
-		return allResourcesConfig, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "k8s", Directory: absRootDir, ErrMessage: err.Error()})
+		return allResourcesConfig, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "k8s", Directory: absRootDir, ErrMessage: err.Error()})
 	}
 
 	for fileDir, files := range fileMap {
@@ -47,39 +45,15 @@ func (k *K8sV1) LoadIacDir(absRootDir string, nonRecursive bool) (output.AllReso
 			if configData, err = k.LoadIacFile(file); err != nil {
 				errMsg := fmt.Sprintf("error while loading iac file '%s'. err: %v", file, err)
 				zap.S().Debug("error while loading iac files", zap.String("IAC file", file), zap.Error(err))
-				errIacLoadDirs = multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "k8s", Directory: fileDir, ErrMessage: errMsg})
+				k.errIacLoadDirs = multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "k8s", Directory: fileDir, ErrMessage: errMsg})
 				continue
 			}
 
 			for key := range configData {
-				// the source path formed for each resources is absolute, which should be relative
-				resourceConfigs := configData[key]
-				makeSourcePathRelative(absRootDir, resourceConfigs)
-
 				allResourcesConfig[key] = append(allResourcesConfig[key], configData[key]...)
 			}
 		}
 	}
 
-	return allResourcesConfig, errIacLoadDirs
-}
-
-// makeSourcePathRelative modifies the source path of each resource from absolute to relative path
-func makeSourcePathRelative(absRootDir string, resourceConfigs []output.ResourceConfig) {
-	for i := range resourceConfigs {
-		r := &resourceConfigs[i]
-		var err error
-
-		oldSource := r.Source
-
-		// update the source path
-		r.Source, err = filepath.Rel(absRootDir, r.Source)
-
-		// though this error should never occur, but, if occurs for some reason, assign the old value of source back
-		if err != nil {
-			r.Source = oldSource
-			zap.S().Debug("error while getting the relative path for", zap.String("IAC file", oldSource), zap.Error(err))
-			continue
-		}
-	}
+	return allResourcesConfig, k.errIacLoadDirs
 }
