@@ -19,8 +19,7 @@ const (
 )
 
 var (
-	kustomizeErrMessage                   = "error from kustomization. error : %v"
-	errIacLoadDirs      *multierror.Error = nil
+	kustomizeErrMessage = "error from kustomization. error : %v"
 )
 
 // LoadIacDir loads the kustomize directory and returns the ResourceConfig mapping which is evaluated by the policy engine
@@ -31,19 +30,19 @@ func (k *KustomizeV3) LoadIacDir(absRootDir string, nonRecursive bool) (output.A
 	files, err := utils.FindFilesBySuffixInDir(absRootDir, KustomizeFileNames())
 	if err != nil {
 		zap.S().Debug("error while searching for iac files", zap.String("root dir", absRootDir), zap.Error(err))
-		return allResourcesConfig, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: err.Error()})
+		return allResourcesConfig, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: err.Error()})
 	}
 
 	if len(files) == 0 {
 		errMsg := fmt.Sprintf("kustomization.y(a)ml file not found in the directory %s", absRootDir)
 		zap.S().Debug("error while searching for iac files", zap.String("root dir", absRootDir), zap.Error(err))
-		return allResourcesConfig, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
+		return allResourcesConfig, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
 	}
 
 	if len(files) > 1 {
 		errMsg := fmt.Sprintf("multiple kustomization.y(a)ml found in the directory %s", absRootDir)
 		zap.S().Debug("error while searching for iac files", zap.String("root dir", absRootDir), zap.Error(err))
-		return allResourcesConfig, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
+		return allResourcesConfig, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
 	}
 
 	kustomizeFileName := *files[0]
@@ -52,7 +51,7 @@ func (k *KustomizeV3) LoadIacDir(absRootDir string, nonRecursive bool) (output.A
 	if err != nil {
 		err = fmt.Errorf("unable to read the kustomization file in the directory %s, error: %v", absRootDir, err)
 		zap.S().Error("error while reading the file", kustomizeFileName, zap.Error(err))
-		return allResourcesConfig, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: err.Error()})
+		return allResourcesConfig, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: err.Error()})
 	}
 
 	// ResourceConfig representing the kustomization.y(a)ml file
@@ -72,7 +71,7 @@ func (k *KustomizeV3) LoadIacDir(absRootDir string, nonRecursive bool) (output.A
 	if err != nil {
 		errMsg := fmt.Sprintf("error occurred while loading kustomize directory '%s'. err: %v", absRootDir, err)
 		zap.S().Error("error occurred while loading kustomize directory", zap.String("kustomize directory", absRootDir), zap.Error(err))
-		return nil, multierror.Append(errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
+		return nil, multierror.Append(k.errIacLoadDirs, results.DirScanErr{IacType: "kustomize", Directory: absRootDir, ErrMessage: errMsg})
 	}
 
 	for _, doc := range iacDocuments {
@@ -91,7 +90,7 @@ func (k *KustomizeV3) LoadIacDir(absRootDir string, nonRecursive bool) (output.A
 		allResourcesConfig[config.Type] = append(allResourcesConfig[config.Type], *config)
 	}
 
-	return allResourcesConfig, errIacLoadDirs
+	return allResourcesConfig, k.errIacLoadDirs
 }
 
 // LoadKustomize loads up a 'kustomized' directory and returns a returns a list of IacDocuments
